// Prevents additional console window on Windows in release, DO NOT REMOVE!!
#![cfg_attr(not(debug_assertions), windows_subsystem = "windows")]

use tauri::{Emitter, Manager};

#[derive(Clone, serde::Serialize)]
struct Payload {
    args: Vec<String>,
}

fn main() {
    tauri::Builder::default()
        .plugin(tauri_plugin_updater::Builder::new().build())
        .plugin(tauri_plugin_shell::init())
        .plugin(tauri_plugin_window_state::Builder::default().build())
        .plugin(tauri_plugin_deep_link::init())
        .plugin(tauri_plugin_single_instance::init(|app, argv, _cwd| {
            let window = app.get_webview_window("main").expect("No window open");

            if window.is_minimized().unwrap_or(true) {
                let _ = window.maximize();
            }
            let _ = window.set_focus();

            let args: Vec<String> = argv.into_iter().skip(1).collect();
            if args.len() != 0 {
                app.emit("open", Payload { args }).unwrap();
            }
        }))
        .setup(|app| {
            let window = app.get_webview_window("main").unwrap();

            let argv: Vec<String> = std::env::args().collect();
            let args: Vec<String> = argv.into_iter().skip(1).collect();

            window.emit("open", Payload { args }).unwrap();

            Ok(())
        })
        .run(tauri::generate_context!())
        .expect("error while running tauri application");
}
